==> MediaWikiLanguageExtensionBundle-2017.01.tar.bz2: extensions/cldr/CldrNames/CldrNamesAk.php <==
<?php

$languageNames = [
	'ak' => 'Akan',
	'am' => 'Amarik',
	'ar' => 'Arabik',
	'be' => 'Belarus kasa',
	'bg' => 'Bɔlgeria kasa',
	'bn' => 'Bengali kasa',
	'cs' => 'Kyɛk kasa',
	'de' => 'Gyaaman',
	'el' => 'Greek kasa',
	'en' => 'Borɔfo',
	'es' => 'Spain kasa',
	'fa' => 'Pɛɛhyia kasa',
	'fr' => 'Frɛnkye',
	'ha' => 'Hausa',
	'hi' => 'Hindi',
	'hu' => 'Hangri kasa',
	'id' => 'Indonihyia kasa',
	'ig' => 'Igbo',
	'it' => 'Italy kasa',
	'ja' => 'Gyapan kasa',
	'jv' => 'Gyabanis kasa',
	'km' => 'Kambodia kasa',
	'ko' => 'Korea kasa',
	'ms' => 'Malay kasa',
	'my' => 'Bɛɛmis kasa',
	'ne' => 'Nɛpal kasa',
	'nl' => 'Dɛɛkye',
	'pa' => 'Pungyabi kasa',
	'pl' => 'Pɔland kasa',
	'pt' => 'Pɔɔtugal kasa',
	'ro' => 'Romenia kasa',
	'ru' => 'Rahyia kasa',
	'rw' => 'Rewanda kasa',
	'so' => 'Somalia kasa',
	'sv' => 'Sweden kasa',
	'ta' => 'Tamil kasa',
	'th' => 'Taeland kasa',
	'tr' => 'Tɛɛki kasa',
	'uk' => 'Ukren kasa',
	'ur' => 'Urdu kasa',
	'vi' => 'Viɛtnam kasa',
	'yo' => 'Yoruba',
	'zh' => 'Kyaena kasa',
	'zu' => 'Zulu',
];

$currencyNames = [
	'AED' => 'Ɛmirete Arab Nkabɔmu Deram',
	'AOA' => 'Angola Kwanza',
	'AUD' => 'Ɔstrelia Dɔla',
	'BHD' => 'Baren Dina',
	'BIF' => 'Burundi Frank',
	'BWP' => 'Botswana Pula',
	'CAD' => 'Kanada Dɔla',
	'CDF' => 'Kongo Frank',
	'CNY' => 'Yuan',
	'CVE' => 'Ɛskudo',
	'DJF' => 'Gyebuti Frank',
	'DZD' => 'Ɔlgyeria Dina',
	'EGP' => 'Egypt Pɔn',
	'ERN' => 'Ɛretereya Nakfa',
	'ETB' => 'Itiopia Bir',
	'EUR' => 'Iro',
	'GBP' => 'Breten Pɔn',
	'GHC' => 'Ghana Sidi (1979–2007)',
	'GHS' => 'Ghana Sidi',
	'GMD' => 'Gambia Dalasi',
	'GNS' => 'Gini Frank',
	'INR' => 'India Rupi',
	'JPY' => 'Gyapan Yɛn',
	'KES' => 'Kenya Hyelen',
	'KMF' => 'Komoro Frank',
	'LRD' => 'Laeberia Dɔla',
	'LSL' => 'Lesoto Loti',
	'LYD' => 'Libya Dina',
	'MAD' => 'Moroko Diram',
	'MGA' => 'Madagasi Frank',
	'MRO' => 'Mɔretenia Ouguiya',
	'MUR' => 'Mɔrehyeɔs Rupi',
	'MWK' => 'Malawi Kwacha',
	'MZM' => 'Mozambik Metical',
	'NAD' => 'Namibia Dɔla',
	'NGN' => 'Naegyeria Naira',
	'RWF' => 'Rewanda Frank',
	'SAR' => 'Saudi Riyal',
	'SCR' => 'Seyhyɛls Rupi',
	'SDG' => 'Sudan Dina',
	'SDP' => 'Sudan Pɔn',
	'SHP' => 'St Helena Pɔn',
	'SLL' => 'Leone',
	'SOS' => 'Somailia Hyelen',
	'STD' => 'Sao Tome ne Principe Dobra',
	'SZL' => 'Lilangeni',
	'TND' => 'Tunisia Dina',
	'TZS' => 'Tanzania Hyelen',
	'UGX' => 'Uganda Hyelen',
	'USD' => 'Amɛrika Dɔla',
	'XAF' => 'Sefa',
	'ZAR' => 'Afrika Anaafo Rand',
	'ZMK' => 'Zambia Kwacha (1968–2012)',
	'ZMW' => 'Zambia Kwacha',
	'ZWD' => 'Zimbabwe Dɔla',
];

$currencySymbols = [
	'GHS' => 'GH₵',
];

$countryNames = [
	'AD' => 'Andora',
	'AE' => 'United Arab Emirates',
	'AF' => 'Afganistan',
	'AG' => 'Antigua ne Baabuda',
	'AI' => 'Anguila',
	'AL' => 'Albenia',
	'AM' => 'Aamenia',
	'AO' => 'Angola',
	'AR' => 'Agyɛntina',
	'AS' => 'Amɛrika Samoa',
	'AT' => 'Ɔstria',
	'AU' => 'Ɔstrelia',
	'AW' => 'Aruba',
	'AZ' => 'Azebaegyan',
	'BA' => 'Bosnia ne Hɛzegovina',
	'BB' => 'Baabados',
	'BD' => 'Bangladɛhye',
	'BE' => 'Bɛlgyium',
	'BF' => 'Bɔkina Faso',
	'BG' => 'Bɔlgeria',
	'BH' => 'Baren',
	'BI' => 'Burundi',
	'BJ' => 'Bɛnin',
	'BM' => 'Bɛmuda',
	'BN' => 'Brunae',
	'BO' => 'Bolivia',
	'BR' => 'Brazil',
	'BS' => 'Bahama',
	'BT' => 'Butan',
	'BW' => 'Bɔtswana',
	'BY' => 'Bɛlarus',
	'BZ' => 'Beliz',
	'CA' => 'Kanada',
	'CD' => 'Kongo (Zair)',
	'CF' => 'Afrika Finimfin Man',
	'CG' => 'Kongo',
	'CH' => 'Swetzaland',
	'CI' => 'La Côte d’Ivoire',
	'CK' => 'Kook Nsupɔw',
	'CL' => 'Kyili',
	'CM' => 'Kamɛrun',
	'CN' => 'Kyaena',
	'CO' => 'Kolombia',
	'CR' => 'Kɔsta Rika',
	'CU' => 'Kuba',
	'CV' => 'Kepvɛdfo Islands',
	'CY' => 'Saeprɔs',
	'CZ' => 'Kyɛk Kurokɛse',
	'DE' => 'Gyaaman',
	'DJ' => 'Gyibuti',
	'DK' => 'Dɛnmak',
	'DM' => 'Dɔmeneka',
	'DO' => 'Dɔmeneka Kurokɛse',
	'DZ' => 'Ɔlgyeria',
	'EC' => 'Ikuwadɔ',
	'EE' => 'Ɛstonia',
	'EG' => 'Nisrim',
	'ER' => 'Ɛritrea',
	'ES' => 'Spain',
	'ET' => 'Ithiopia',
	'FI' => 'Finland',
	'FJ' => 'Figyi',
	'FK' => 'Fɔlkman Aeland',
	'FM' => 'Maekronehyia',
	'FR' => 'Frɛnkyeman',
	'GA' => 'Gabɔn',
	'GB' => 'Ahendiman Nkabom',
	'GD' => 'Grenada',
	'GE' => 'Gyɔgyea',
	'GF' => 'Frɛnkye Gayana',
	'GH' => 'Gaana',
	'GI' => 'Gyebralta',
	'GL' => 'Greenman',
	'GM' => 'Gambia',
	'GN' => 'Gini',
	'GP' => 'Guwadelup',
	'GQ' => 'Gini Ikuweta',
	'GR' => 'Greekman',
	'GT' => 'Guwatemala',
	'GU' => 'Guam',
	'GW' => 'Gini Bisaw',
	'GY' => 'Gayana',
	'HN' => 'Hɔnduras',
	'HR' => 'Krowehyia',
	'HT' => 'Heiti',
	'HU' => 'Hangari',
	'ID' => 'Indɔnehyia',
	'IE' => 'Aereland',
	'IL' => 'Israel',
	'IN' => 'India',
	'IO' => 'Britenfo Hɔn Man Wɔ India Po No Mu',
	'IQ' => 'Irak',
	'IR' => 'Iran',
	'IS' => 'Aesland',
	'IT' => 'Itali',
	'JM' => 'Gyameka',
	'JO' => 'Gyɔdan',
	'JP' => 'Gyapan',
	'KE' => 'Kɛnya',
	'KG' => 'Kɛɛgestan',
	'KH' => 'Kambodia',
	'KI' => 'Kiribati',
	'KM' => 'Kɔmɔrɔs',
	'KN' => 'Saint Kitts ne Nɛves',
	'KP' => 'Etifi Koria',
	'KR' => 'Anaafo Koria',
	'KW' => 'Kuwete',
	'KY' => 'Kemanfo Islands',
	'KZ' => 'Kazakstan',
	'LA' => 'Laos',
	'LB' => 'Lɛbanɔn',
	'LC' => 'Saint Lucia',
	'LI' => 'Lektenstaen',
	'LK' => 'Sri Lanka',
	'LR' => 'Laeberia',
	'LS' => 'Lɛsutu',
	'LT' => 'Lituwenia',
	'LU' => 'Laksembɛg',
	'LV' => 'Latvia',
	'LY' => 'Libya',
	'MA' => 'Moroko',
	'MC' => 'Mɔnako',
	'MD' => 'Mɔldova',
	'MG' => 'Madagaska',
	'MH' => 'Marshall Islands',
	'MK' => 'Masedonia',
	'ML' => 'Mali',
	'MM' => 'Miyanma',
	'MN' => 'Mɔngolia',
	'MP' => 'Northern Mariana Islands',
	'MQ' => 'Matinik',
	'MR' => 'Mɔretenia',
	'MS' => 'Mantserat',
	'MT' => 'Mɔlta',
	'MU' => 'Mɔrehyeɔs',
	'MV' => 'Maldives',
	'MW' => 'Malawi',
	'MX' => 'Mɛksiko',
	'MY' => 'Malehyia',
	'MZ' => 'Mozambik',
	'NA' => 'Namibia',
	'NC' => 'Kaledonia Foforo',
	'NE' => 'Nigyɛ',
	'NF' => 'Nɔfolk Aeland',
	'NG' => 'Naegyeria',
	'NI' => 'Nekaraguwa',
	'NL' => 'Nɛdɛland',
	'NO' => 'Nɔɔwe',
	'NP' => 'Nɛpɔl',
	'NR' => 'Naworu',
	'NU' => 'Niyu',
	'NZ' => 'Ziland Foforo',
	'OM' => 'Oman',
	'PA' => 'Panama',
	'PE' => 'Peru',
	'PF' => 'Frɛnkye Pɔlenehyia',
	'PG' => 'Papua Guinea Foforo',
	'PH' => 'Philippines',
	'PK' => 'Pakistan',
	'PL' => 'Poland',
	'PM' => 'Saint Pierre ne Miquelon',
	'PN' => 'Pitcairn',
	'PR' => 'Puɛto Riko',
	'PS' => 'Palestaen West Bank ne Gaza',
	'PT' => 'Pɔtugal',
	'PW' => 'Palau',
	'PY' => 'Paraguay',
	'QA' => 'Kata',
	'RE' => 'Reyuniɔn',
	'RO' => 'Romenia',
	'RU' => 'Rɔhyea',
	'RW' => 'Rwanda',
	'SA' => 'Saudi Arabia',
	'SB' => 'Solomon Islands',
	'SC' => 'Seyhyɛl',
	'SD' => 'Sudan',
	'SE' => 'Sweden',
	'SG' => 'Singapɔ',
	'SH' => 'Saint Helena',
	'SI' => 'Slovinia',
	'SK' => 'Slovakia',
	'SL' => 'Sierra Leone',
	'SM' => 'San Marino',
	'SN' => 'Senegal',
	'SO' => 'Somalia',
	'SR' => 'Suriname',
	'ST' => 'São Tomé and Príncipe',
	'SV' => 'Ɛl Salvadɔ',
	'SY' => 'Siria',
	'SZ' => 'Swaziland',
	'TC' => 'Turks ne Caicos Islands',
	'TD' => 'Kyad',
	'TG' => 'Togo',
	'TH' => 'Taeland',
	'TJ' => 'Tajikistan',
	'TK' => 'Tokelau',
	'TL' => 'Timɔ Boka',
	'TM' => 'Tɛkmɛnistan',
	'TN' => 'Tunihyia',
	'TO' => 'Tonga',
	'TR' => 'Tɛɛki',
	'TT' => 'Trinidad ne Tobago',
	'TV' => 'Tuvalu',
	'TW' => 'Taiwan',
	'TZ' => 'Tanzania',
	'UA' => 'Ukren',
	'UG' => 'Uganda',
	'US' => 'Amɛrika',
	'UY' => 'Yurugwae',
	'UZ' => 'Uzbɛkistan',
	'VA' => 'Vatican Man',
	'VC' => 'Saint Vincent ne Grenadines',
	'VE' => 'Venezuela',
	'VG' => 'Britainfo Virgin Islands',
	'VI' => 'Amɛrika Virgin Islands',
	'VN' => 'Viɛtnam',
	'VU' => 'Vanuatu',
	'WF' => 'Wallis ne Futuna',
	'WS' => 'Samoa',
	'YE' => 'Yɛmen',
	'YT' => 'Mayɔte',
	'ZA' => 'Afrika Anaafo',
	'ZM' => 'Zambia',
	'ZW' => 'Zembabwe',
];

==> MediaWikiLanguageExtensionBundle-2019.04.tar.bz2: extensions/cldr/CldrNames/CldrNamesAk.php <==
<?php

$languageNames = [
	'ak' => 'Akan',
	'am' => 'Amarik',
	'ar' => 'Arabik',
	'be' => 'Belarus kasa',
	'bg' => 'Bɔlgeria kasa',
	'bn' => 'Bengali kasa',
	'cs' => 'Kyɛk kasa',
	'de' => 'Gyaaman',
	'el' => 'Greek kasa',
	'en' => 'Borɔfo',
	'es' => 'Spain kasa',
	'fa' => 'Pɛɛhyia kasa',
	'fr' => 'Frɛnkye',
	'ha' => 'Hausa',
	'hi' => 'Hindi',
	'hu' => 'Hangri kasa',
	'id' => 'Indonihyia kasa',
	'ig' => 'Igbo',
	'it' => 'Italy kasa',
	'ja' => 'Gyapan kasa',
	'jv' => 'Gyabanis kasa',
	'km' => 'Kambodia kasa',
	'ko' => 'Korea kasa',
	'ms' => 'Malay kasa',
	'my' => 'Bɛɛmis kasa',
	'ne' => 'Nɛpal kasa',
	'nl' => 'Dɛɛkye',
	'pa' => 'Pungyabi kasa',
	'pl' => 'Pɔland kasa',
	'pt' => 'Pɔɔtugal kasa',
	'ro' => 'Romenia kasa',
	'ru' => 'Rahyia kasa',
	'rw' => 'Rewanda kasa',
	'so' => 'Somalia kasa',
	'sv' => 'Sweden kasa',
	'ta' => 'Tamil kasa',
	'th' => 'Taeland kasa',
	'tr' => 'Tɛɛki kasa',
	'uk' => 'Ukren kasa',
	'ur' => 'Urdu kasa',
	'vi' => 'Viɛtnam kasa',
	'yo' => 'Yoruba',
	'zh' => 'Kyaena kasa',
	'zu' => 'Zulu',
];

$currencyNames = [
	'AED' => 'Ɛmirete Arab Nkabɔmu Deram',
	'AOA' => 'Angola Kwanza',
	'AUD' => 'Ɔstrelia Dɔla',
	'BHD' => 'Baren Dina',
	'BIF' => 'Burundi Frank',
	'BWP' => 'Botswana Pula',
	'CAD' => 'Kanada Dɔla',
	'CDF' => 'Kongo Frank',
	'CNY' => 'Yuan',
	'CVE' => 'Ɛskudo',
	'DJF' => 'Gyebuti Frank',
	'DZD' => 'Ɔlgyeria Dina',
	'EGP' => 'Egypt Pɔn',
	'ERN' => 'Ɛretereya Nakfa',
	'ETB' => 'Itiopia Bir',
	'EUR' => 'Iro',
	'GBP' => 'Breten Pɔn',
	'GHC' => 'Ghana Sidi (1979–2007)',
	'GHS' => 'Ghana Sidi',
	'GMD' => 'Gambia Dalasi',
	'GNS' => 'Gini Frank',
	'INR' => 'India Rupi',
	'JPY' => 'Gyapan Yɛn',
	'KES' => 'Kenya Hyelen',
	'KMF' => 'Komoro Frank',
	'LRD' => 'Laeberia Dɔla',
	'LSL' => 'Lesoto Loti',
	'LYD' => 'Libya Dina',
	'MAD' => 'Moroko Diram',
	'MGA' => 'Madagasi Frank',
	'MRO' => 'Mɔretenia Ouguiya (1973–2017)',
	'MRU' => 'Mɔretenia Ouguiya',
	'MUR' => 'Mɔrehyeɔs Rupi',
	'MWK' => 'Malawi Kwacha',
	'MZM' => 'Mozambik Metical',
	'NAD' => 'Namibia Dɔla',
	'NGN' => 'Naegyeria Naira',
	'RWF' => 'Rewanda Frank',
	'SAR' => 'Saudi Riyal',
	'SCR' => 'Seyhyɛls Rupi',
	'SDG' => 'Sudan Dina',
	'SDP' => 'Sudan Pɔn',
	'SHP' => 'St Helena Pɔn',
	'SLL' => 'Leone',
	'SOS' => 'Somailia Hyelen',
	'STD' => 'Sao Tome ne Principe Dobra (1977–2017)',
	'STN' => 'Sao Tome ne Principe Dobra',
	'SZL' => 'Lilangeni',
	'TND' => 'Tunisia Dina',
	'TZS' => 'Tanzania Hyelen',
	'UGX' => 'Uganda Hyelen',
	'USD' => 'Amɛrika Dɔla',
	'XAF' => 'Sefa',
	'ZAR' => 'Afrika Anaafo Rand',
	'ZMK' => 'Zambia Kwacha (1968–2012)',
	'ZMW' => 'Zambia Kwacha',
	'ZWD' => 'Zimbabwe Dɔla',
];

$currencySymbols = [
	'GHS' => 'GH₵',
];

$countryNames = [
	'AD' => 'Andora',
	'AE' => 'United Arab Emirates',
	'AF' => 'Afganistan',
	'AG' => 'Antigua ne Baabuda',
	'AI' => 'Anguila',
	'AL' => 'Albenia',
	'AM' => 'Aamenia',
	'AO' => 'Angola',
	'AR' => 'Agyɛntina',
	'AS' => 'Amɛrika Samoa',
	'AT' => 'Ɔstria',
	'AU' => 'Ɔstrelia',
	'AW' => 'Aruba',
	'AZ' => 'Azebaegyan',
	'BA' => 'Bosnia ne Hɛzegovina',
	'BB' => 'Baabados',
	'BD' => 'Bangladɛhye',
	'BE' => 'Bɛlgyium',
	'BF' => 'Bɔkina Faso',
	'BG' => 'Bɔlgeria',
	'BH' => 'Baren',
	'BI' => 'Burundi',
	'BJ' => 'Bɛnin',
	'BM' => 'Bɛmuda',
	'BN' => 'Brunae',
	'BO' => 'Bolivia',
	'BR' => 'Brazil',
	'BS' => 'Bahama',
	'BT' => 'Butan',
	'BW' => 'Bɔtswana',
	'BY' => 'Bɛlarus',
	'BZ' => 'Beliz',
	'CA' => 'Kanada',
	'CD' => 'Kongo (Zair)',
	'CF' => 'Afrika Finimfin Man',
	'CG' => 'Kongo',
	'CH' => 'Swetzaland',
	'CI' => 'La Côte d’Ivoire',
	'CK' => 'Kook Nsupɔw',
	'CL' => 'Kyili',
	'CM' => 'Kamɛrun',
	'CN' => 'Kyaena',
	'CO' => 'Kolombia',
	'CR' => 'Kɔsta Rika',
	'CU' => 'Kuba',
	'CV' => 'Kepvɛdfo Islands',
	'CY' => 'Saeprɔs',
	'CZ' => 'Kyɛk Kurokɛse',
	'DE' => 'Gyaaman',
	'DJ' => 'Gyibuti',
	'DK' => 'Dɛnmak',
	'DM' => 'Dɔmeneka',
	'DO' => 'Dɔmeneka Kurokɛse',
	'DZ' => 'Ɔlgyeria',
	'EC' => 'Ikuwadɔ',
	'EE' => 'Ɛstonia',
	'EG' => 'Nisrim',
	'ER' => 'Ɛritrea',
	'ES' => 'Spain',
	'ET' => 'Ithiopia',
	'FI' => 'Finland',
	'FJ' => 'Figyi',
	'FK' => 'Fɔlkman Aeland',
	'FM' => 'Maekronehyia',
	'FR' => 'Frɛnkyeman',
	'GA' => 'Gabɔn',
	'GB' => 'Ahendiman Nkabom',
	'GD' => 'Grenada',
	'GE' => 'Gyɔgyea',
	'GF' => 'Frɛnkye Gayana',
	'GH' => 'Gaana',
	'GI' => 'Gyebralta',
	'GL' => 'Greenman',
	'GM' => 'Gambia',
	'GN' => 'Gini',
	'GP' => 'Guwadelup',
	'GQ' => 'Gini Ikuweta',
	'GR' => 'Greekman',
	'GT' => 'Guwatemala',
	'GU' => 'Guam',
	'GW' => 'Gini Bisaw',
	'GY' => 'Gayana',
	'HN' => 'Hɔnduras',
	'HR' => 'Krowehyia',
	'HT' => 'Heiti',
	'HU' => 'Hangari',
	'ID' => 'Indɔnehyia',
	'IE' => 'Aereland',
	'IL' => 'Israel',
	'IN' => 'India',
	'IO' => 'Britenfo Hɔn Man Wɔ India Po No Mu',
	'IQ' => 'Irak',
	'IR' => 'Iran',
	'IS' => 'Aesland',
	'IT' => 'Itali',
	'JM' => 'Gyameka',
	'JO' => 'Gyɔdan',
	'JP' => 'Gyapan',
	'KE' => 'Kɛnya',
	'KG' => 'Kɛɛgestan',
	'KH' => 'Kambodia',
	'KI' => 'Kiribati',
	'KM' => 'Kɔmɔrɔs',
	'KN' => 'Saint Kitts ne Nɛves',
	'KP' => 'Etifi Koria',
	'KR' => 'Anaafo Koria',
	'KW' => 'Kuwete',
	'KY' => 'Kemanfo Islands',
	'KZ' => 'Kazakstan',
	'LA' => 'Laos',
	'LB' => 'Lɛbanɔn',
	'LC' => 'Saint Lucia',
	'LI' => 'Lektenstaen',
	'LK' => 'Sri Lanka',
	'LR' => 'Laeberia',
	'LS' => 'Lɛsutu',
	'LT' => 'Lituwenia',
	'LU' => 'Laksembɛg',
	'LV' => 'Latvia',
	'LY' => 'Libya',
	'MA' => 'Moroko',
	'MC' => 'Mɔnako',
	'MD' => 'Mɔldova',
	'MG' => 'Madagaska',
	'MH' => 'Marshall Islands',
	'MK' => 'Masedonia',
	'ML' => 'Mali',
	'MM' => 'Miyanma',
	'MN' => 'Mɔngolia',
	'MP' => 'Northern Mariana Islands',
	'MQ' => 'Matinik',
	'MR' => 'Mɔretenia',
	'MS' => 'Mantserat',
	'MT' => 'Mɔlta',
	'MU' => 'Mɔrehyeɔs',
	'MV' => 'Maldives',
	'MW' => 'Malawi',
	'MX' => 'Mɛksiko',
	'MY' => 'Malehyia',
	'MZ' => 'Mozambik',
	'NA' => 'Namibia',
	'NC' => 'Kaledonia Foforo',
	'NE' => 'Nigyɛ',
	'NF' => 'Nɔfolk Aeland',
	'NG' => 'Naegyeria',
	'NI' => 'Nekaraguwa',
	'NL' => 'Nɛdɛland',
	'NO' => 'Nɔɔwe',
	'NP' => 'Nɛpɔl',
	'NR' => 'Naworu',
	'NU' => 'Niyu',
	'NZ' => 'Ziland Foforo',
	'OM' => 'Oman',
	'PA' => 'Panama',
	'PE' => 'Peru',
	'PF' => 'Frɛnkye Pɔlenehyia',
	'PG' => 'Papua Guinea Foforo',
	'PH' => 'Philippines',
	'PK' => 'Pakistan',
	'PL' => 'Poland',
	'PM' => 'Saint Pierre ne Miquelon',
	'PN' => 'Pitcairn',
	'PR' => 'Puɛto Riko',
	'PS' => 'Palestaen West Bank ne Gaza',
	'PT' => 'Pɔtugal',
	'PW' => 'Palau',
	'PY' => 'Paraguay',
	'QA' => 'Kata',
	'RE' => 'Reyuniɔn',
	'RO' => 'Romenia',
	'RU' => 'Rɔhyea',
	'RW' => 'Rwanda',
	'SA' => 'Saudi Arabia',
	'SB' => 'Solomon Islands',
	'SC' => 'Seyhyɛl',
	'SD' => 'Sudan',
	'SE' => 'Sweden',
	'SG' => 'Singapɔ',
	'SH' => 'Saint Helena',
	'SI' => 'Slovinia',
	'SK' => 'Slovakia',
	'SL' => 'Sierra Leone',
	'SM' => 'San Marino',
	'SN' => 'Senegal',
	'SO' => 'Somalia',
	'SR' => 'Suriname',
	'ST' => 'São Tomé and Príncipe',
	'SV' => 'Ɛl Salvadɔ',
	'SY' => 'Siria',
	'SZ' => 'Swaziland',
	'TC' => 'Turks ne Caicos Islands',
	'TD' => 'Kyad',
	'TG' => 'Togo',
	'TH' => 'Taeland',
	'TJ' => 'Tajikistan',
	'TK' => 'Tokelau',
	'TL' => 'Timɔ Boka',
	'TM' => 'Tɛkmɛnistan',
	'TN' => 'Tunihyia',
	'TO' => 'Tonga',
	'TR' => 'Tɛɛki',
	'TT' => 'Trinidad ne Tobago',
	'TV' => 'Tuvalu',
	'TW' => 'Taiwan',
	'TZ' => 'Tanzania',
	'UA' => 'Ukren',
	'UG' => 'Uganda',
	'US' => 'Amɛrika',
	'UY' => 'Yurugwae',
	'UZ' => 'Uzbɛkistan',
	'VA' => 'Vatican Man',
	'VC' => 'Saint Vincent ne Grenadines',
	'VE' => 'Venezuela',
	'VG' => 'Britainfo Virgin Islands',
	'VI' => 'Amɛrika Virgin Islands',
	'VN' => 'Viɛtnam',
	'VU' => 'Vanuatu',
	'WF' => 'Wallis ne Futuna',
	'WS' => 'Samoa',
	'YE' => 'Yɛmen',
	'YT' => 'Mayɔte',
	'ZA' => 'Afrika Anaafo',
	'ZM' => 'Zambia',
	'ZW' => 'Zembabwe',
];
